# Pyscilog 🍄

Pyscilog, the Python scientific logger, is a companion for the standard Python logging library. It supports the
reporting of various metrics, such as memory usage and system load. This library is typically useful in high performance
and scientific software development settings.

# installation

```
pip install pyscilog
```
